package org.gcube.datacatalogue.ckanutillibrary.gcat;

import java.io.IOException;
import java.net.MalformedURLException;

import org.gcube.gcat.client.Item;
import org.gcube.gcat.client.Resource;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

// TODO: Auto-generated Javadoc
/**
 * The Class GCatCaller.
 *
 * @author Francesco Mangiacrapa at ISTI-CNR Pisa (Italy)
 * May 29, 2020
 */
public class GCatCaller {
	
	private String catalogueURL;
	
	private static final Logger LOG = LoggerFactory.getLogger(GCatCaller.class);
	
	/**
	 * Instantiates a new g cat caller.
	 *
	 * @param catalogueURL the catalogue URL
	 */
	public GCatCaller(String catalogueURL) {
		this.catalogueURL = catalogueURL;
	}
	
	
	/**
	 * Gets the dataset for name.
	 *
	 * @param datasetIdOrName the dataset id or name
	 * @return the jsonValue
	 * @throws MalformedURLException 
	 * @throws IOException Signals that an I/O exception has occurred.
	 */
	public String getDatasetForName(String datasetIdOrName) throws MalformedURLException {
		LOG.debug("Get dataset for name "+datasetIdOrName+ "called");
		return new Item().read(datasetIdOrName);
	}
	
	
	/**
	 * Creates the dataset.
	 *
	 * @param jsonDataset the json dataset
	 * @param socialPost if true sends the social post
	 * @return the jsonValue
	 * @throws MalformedURLException the malformed URL exception
	 */
	public String createDataset(String jsonDataset, boolean socialPost) throws MalformedURLException {
		LOG.debug("Create dataset called");
		return new Item().create(jsonDataset,socialPost);
	}
	
	
	public String addResourceToDataset(String datasetID, String jsonValueResource) throws MalformedURLException {
		LOG.debug("Create resource called");
		return new Resource().create(datasetID, jsonValueResource);
	}
	
	
	public String getCatalogueURL() {
		return catalogueURL;
	}

}
